@@ -2,24 +2,33 @@
 
 import json
 import sys
-from asyncio import run
 from datetime import datetime, timezone
+from functools import update_wrapper
+from importlib.metadata import version
 from os import getenv
+from platform import system
 from typing import Any, Callable, Dict
 
 import click
 import requests
+from fideslog.sdk.python.client import AnalyticsClient
 from fideslog.sdk.python.event import AnalyticsEvent
-from fideslog.sdk.python.exceptions import AnalyticsException
-from fideslog.sdk.python.utils import OPT_OUT_COPY
+from fideslog.sdk.python.exceptions import AnalyticsError
+from fideslog.sdk.python.utils import (
+    FIDESCTL_CLI,
+    OPT_OUT_COPY,
+    OPT_OUT_PROMPT,
+    generate_client_id,
+)
 
+import fidesctl
 from fidesctl.core import api as _api
 from fidesctl.core.config.utils import get_config_from_file, update_config_file
 from fidesctl.core.utils import check_response, echo_green, echo_red
 
 
 def check_server(cli_version: str, server_url: str) -> None:
-    "Runs a health check and a version check against the server."
+    """Runs a health check and a version check against the server."""
 
     healthcheck_url = server_url + "/health"
     try:
@@ -74,8 +83,9 @@ def check_and_update_analytics_config(ctx: click.Context, config_path: str) -> N
 
     config_updates: Dict[str, Dict] = {}
     if ctx.obj["CONFIG"].user.analytics_opt_out is None:
+        click.echo(OPT_OUT_COPY)
         ctx.obj["CONFIG"].user.analytics_opt_out = bool(
-            input(OPT_OUT_COPY).lower() == "n"
+            input(OPT_OUT_PROMPT).lower() == "n"
         )
 
         config_updates.update(
@@ -101,43 +111,79 @@ def check_and_update_analytics_config(ctx: click.Context, config_path: str) -> N
             click.echo("Run 'fidesctl init' to create a configuration file.")
 
 
-def with_analytics(ctx: click.Context, command_handler: Callable, **kwargs: Dict) -> Any:  # type: ignore
+def send_init_analytics(opt_out: bool, config_path: str, executed_at: datetime) -> None:
     """
-    Send an `AnalyticsEvent` with details about the executed command,
-    as long as the CLI has not been configured to opt out of analytics.
-
-    :param ctx: The command's execution `click.Context` object
-    :param command_handler: The handler function defining the evaluation logic for the analyzed command
-    :param **kwargs: Any arguments that must be passed to the `command_handler` function
+    Create a new `AnalyticsClient` and send an `AnalyticsEvent` representing
+    the execution of `fidesctl init` by a user.
     """
 
-    command = " ".join(filter(None, [ctx.info_name, ctx.invoked_subcommand]))
-    error = None
-    executed_at = datetime.now(timezone.utc)
-    status_code = 0
+    if opt_out is not False:
+        return
+
+    analytics_id = get_config_from_file(config_path, "cli", "analytics_id")
+    app_name = fidesctl.__name__
 
     try:
-        return command_handler(**kwargs)
-    except Exception as err:
-        error = type(err).__name__
-        status_code = 1
-        raise err
-    finally:
-        if (
-            ctx.obj["CONFIG"].user.analytics_opt_out is False
-        ):  # requires explicit opt-in
-            event = AnalyticsEvent(
-                "cli_command_executed",
-                executed_at,
-                command=command,
-                docker=bool(getenv("RUNNING_IN_DOCKER") == "TRUE"),
-                error=error,
-                flags=None,  # TODO: Figure out if it's possible to capture this
-                resource_counts=None,  # TODO: Figure out if it's possible to capture this
-                status_code=status_code,
-            )
+        client = AnalyticsClient(
+            client_id=analytics_id or generate_client_id(FIDESCTL_CLI),
+            developer_mode=bool(getenv("FIDESCTL_TEST_MODE") == "True"),
+            os=system(),
+            product_name=app_name + "-cli",
+            production_version=version(app_name),
+        )
 
-            try:
-                run(ctx.meta["ANALYTICS_CLIENT"].send(event))
-            except AnalyticsException:
-                pass  # cli analytics should fail silently
+        event = AnalyticsEvent(
+            "cli_command_executed",
+            executed_at,
+            command="fidesctl init",
+            docker=bool(getenv("RUNNING_IN_DOCKER") == "TRUE"),
+            resource_counts=None,  # TODO: Figure out if it's possible to capture this
+        )
+
+        client.send(event)
+    except AnalyticsError:
+        pass  # cli analytics should fail silently
+
+
+def with_analytics(func: Callable) -> Callable:
+    """
+    Click command decorator which can be added to enable publishing anaytics.
+    Sends an `AnalyticsEvent` with details about the executed command,
+    as long as the CLI has not been configured to opt out of analytics.
+
+    :param func: function to be wrapped by decorator
+    """
+
+    def wrapper_func(ctx: click.Context, *args, **kwargs) -> Any:  # type: ignore
+        command = " ".join(filter(None, [ctx.info_name, ctx.invoked_subcommand]))
+        error = None
+        executed_at = datetime.now(timezone.utc)
+        status_code = 0
+
+        try:
+            return ctx.invoke(func, ctx, *args, **kwargs)
+        except Exception as err:
+            error = type(err).__name__
+            status_code = 1
+            raise err
+        finally:
+            if (
+                ctx.obj["CONFIG"].user.analytics_opt_out is False
+            ):  # requires explicit opt-in
+                event = AnalyticsEvent(
+                    "cli_command_executed",
+                    executed_at,
+                    command=command,
+                    docker=bool(getenv("RUNNING_IN_DOCKER") == "TRUE"),
+                    error=error,
+                    flags=None,  # TODO: Figure out if it's possible to capture this
+                    resource_counts=None,  # TODO: Figure out if it's possible to capture this
+                    status_code=status_code,
+                )
+
+                try:
+                    ctx.meta["ANALYTICS_CLIENT"].send(event)
+                except AnalyticsError:
+                    pass  # cli analytics should fail silently
+
+    return update_wrapper(wrapper_func, func)
