@@ -1,18 +1,18 @@
 """Module that adds functionality for generating or scanning systems."""
 from collections import defaultdict
-from typing import Dict, List, Tuple, Optional
+from typing import Dict, List, Optional, Tuple
 
 from pydantic import AnyHttpUrl
 
 from fidesctl.cli.utils import handle_cli_response
 from fidesctl.core import api
+from fidesctl.core.api_helpers import get_server_resource, get_server_resources
 from fidesctl.core.parse import parse
-from fidesctl.core.api_helpers import get_server_resources, get_server_resource
 from fideslang import manifests
 from fideslang.models import Organization, System, SystemMetadata
 
-from .utils import echo_green, echo_red
 from .filters import filter_aws_systems
+from .utils import echo_green, echo_red
 
 
 def describe_redshift_clusters() -> Dict[str, List[Dict]]:
