@@ -6,14 +6,14 @@ from __future__ import annotations
 from enum import Enum
 from typing import Dict, List, Optional
 
-from pydantic import root_validator, validator, BaseModel, Field, AnyUrl, HttpUrl
+from pydantic import AnyUrl, BaseModel, Field, HttpUrl, root_validator, validator
 
 from fideslang.validation import (
     FidesKey,
-    sort_list_objects_by_name,
-    no_self_reference,
-    matching_parent_key,
     check_valid_country_code,
+    matching_parent_key,
+    no_self_reference,
+    sort_list_objects_by_name,
 )
 
 # Reusable components
@@ -52,6 +52,7 @@ class FidesModel(BaseModel):
         "Config for the FidesModel"
         extra = "ignore"
         orm_mode = True
+        use_enum_values = True
 
 
 class DataResponsibilityTitle(str, Enum):
@@ -686,10 +687,6 @@ class System(FidesModel):
 
     _check_valid_country_code: classmethod = country_code_validator
 
-    class Config:
-        "Class for the System config"
-        use_enum_values = True
-
 
 # Taxonomy
 class Taxonomy(BaseModel):
